/* ******************************************************************

   author     : puehringer edgar

   compiler   : javac (jdk 1.1.5)

   class      : FileDatabase
   date       : 16.10.97
   description: a class that implements basic database operations
                for calendar queries
   modified   : 09.02.98 - bug in filename creation fixed
                11.02.98 - bug in updateDate removed
                19.03.98 - bug with not deleted error strings removed

*********************************************************************/

/* ******************************************************************
   import statements
*********************************************************************/

import java.io.*;
import java.util.*;
import java.text.SimpleDateFormat;

/* ******************************************************************
   top level class declaration
*********************************************************************/

public class FileDatabase implements CalendarDatabase {

  // class variable declaration
  private final static String STANDARD_EXT = ".cal";
  private final static String MESSAGE_EXT  = ".msg";
  private final static String PERIODIC_EXT = ".per";

  // instance variable declaration
  private PwdTable pwdTable;
  private FilePool filePool;
  private boolean logedInFlag;
  private String user;
  private String errStr;
  private SimpleDateFormat formatter;

  // constructors
  public FileDatabase(PwdTable pwdTable, FilePool filePool) {
    this.pwdTable = pwdTable;
    this.filePool = filePool;
    logedInFlag   = false;
    user          = "";
    errStr        = null;
    formatter     = new SimpleDateFormat("yyyyMM",CalendarCreator.getLocale());
  } // end constructor FileDatabase

  // methods
  public boolean failed() {
  // returns true if the last database operation failed
    return (errStr != null);
  } // end failed

  public String getErrorMsg() {
  // returns a string describing the last error
    return errStr;
  } // end getErrorMsg

  public void login(String user, String passwd) {
    String cypheredPasswd = (new PasswdCypher()).cypher(passwd);

    loginCyphered(user,cypheredPasswd);
  } // end login

  public void loginCyphered(String user, String passwd) {
    if (!pwdTable.containsKey(user)) {
      errStr   = "Unknown user\n"+
                 "User "+'"'+user+'"'+" not found in accout list";
      return;
    } // end if
    if (!pwdTable.getPassword(user).equals(passwd)) {
      errStr   = "Wrong password\n"+
                 "User "+'"'+user+'"'+" entered a wrong password";
      return;
    } // end if
    logedInFlag = true;
    this.user   = user;
    errStr      = null;
  } // end loginCyphered

  public void logout() {
    logedInFlag = false;
    user        = "";
    errStr      = null;
  } // end logout

  public void changePasswd(String newPasswd) {
    String cypheredPasswd = (new PasswdCypher()).cypher(newPasswd);
 
    changePasswdCyphered(cypheredPasswd);
  } // end changePasswd

  public void changePasswdCyphered(String newPasswd) {
    if (!logedIn()) return;

    errStr = null;
    try {
      pwdTable.changePassword(user,newPasswd);
    } catch (IOException excep) {
      errStr   = "File I/O error while changing password\n"+
                 excep.toString();
    }
  } // end changePasswdCyphered

  public String[] getUsers() {
    if (!logedIn()) return null;

    int nrOfElem    = pwdTable.size();
    Enumeration e   = pwdTable.keys();
    String[] result = new String[nrOfElem];
    int i;

    for (i=0; i<nrOfElem; i++) {
      result[i] = (String)e.nextElement();
    } // end for
    errStr = null;
    return result;
  } // end getUsers

  public Enumeration getDates(String user, Date from, Date to,
                              boolean periodical) {
    errStr = null;
    if (!logedIn()) return null;
    Enumeration result;

    if (periodical) {
      // periodic dates are fully enumerated
      String fName  = pwdTable.getFileNameShortcut(user)+PERIODIC_EXT;
      try {
        result = new SingleFileEnumeration(this,fName,this.user,false);
      } catch (IOException excep) {
        result = null;
      }
    }
    else {
      try {
        result = new MultipleFileEnumeration(this,
                         pwdTable.getFileNameShortcut(user),
                         STANDARD_EXT,this.user,from,to);
      } catch (IOException excep) {
        result = null;
      }
    } // end if
    return result;
  } // end getDates

  public Enumeration getMessages() {
  // reads new dates written from other users (destructive read)
    errStr = null;
    if (!logedIn()) return null;
    Enumeration result;

    String fName  = pwdTable.getFileNameShortcut(user)+MESSAGE_EXT;
    try {
      result = new SingleFileEnumeration(this,fName,user,true);
    } catch (IOException excep) {
      result = null;
    }
    return result;
  } // end getMessages

  public void putDate(CalendarEntry cEntry) {
    if ((!logedIn()) || (cEntry.isDeleted())) return;
    String persons[]      = cEntry.getPersons();
    Date start            = cEntry.getStart();
    boolean periodic      = cEntry.isPeriodic();
    Vector fNames         = new Vector();
    String errors         = "";
    CalendarFile cFile;
    int i,n;

    cEntry.setCreator(user);
    fNames.addElement(makeFileName(user,start,periodic));
    for (i=0; i<persons.length; i++) {
      if (pwdTable.containsKey(persons[i])) {
        fNames.addElement(makeFileName(persons[i],start,periodic));
        fNames.addElement(pwdTable.getFileNameShortcut(persons[i])+MESSAGE_EXT);
      }
      else {
        if (errors.equals("")) 
          errors = "\nUnknown user(s): "+'"'+persons[i]+'"';
        else
          errors = errors+", "+'"'+persons[i]+'"';
        // end if
      } // end if
    } // end for
    n = fNames.size();
    for (i=0; i<n; i++) {
      cFile = filePool.get((String)fNames.elementAt(i));
      try {
        cFile.write(cEntry);
      } catch (IOException excep) {
        errors = errors+"\nError during write operation on file "+
                 '"'+(String)fNames.elementAt(i)+'"'+"\n"+excep.toString();
        try { filePool.release((String)fNames.elementAt(i));
        } catch (IOException e) {}
      }
      try {
        filePool.release((String)fNames.elementAt(i));
      } catch (IOException excep) {
        errors = errors+"\nError during close operation on file "+
                 '"'+(String)fNames.elementAt(i)+'"'+"\n"+excep.toString();
      }
    } // end for
    if (errors.equals("")) errStr = null;
      else errStr = "Error(s) during write of date"+errors;
  } // end putDate

  public void deleteDate(CalendarEntry cEntry, boolean forAll) {
    if ((!logedIn()) || (cEntry.isDeleted())) return;
    // a date can't be deleted for all if user isn't the creator of it
    if (forAll && (!user.equals(cEntry.getCreator()))) forAll = false;
    String persons[]      = cEntry.getPersons();
    Date start            = cEntry.getStart();
    boolean periodic      = cEntry.isPeriodic();
    Vector fNames         = new Vector();
    String errors         = "";
    CalendarFile cFile;
    int i,j,n;

    fNames.addElement(makeFileName(user,start,periodic));
    if (forAll) for (i=0; i<persons.length; i++) {
      if (pwdTable.containsKey(persons[i])) {
        fNames.addElement(makeFileName(persons[i],start,periodic));
      }
      else {
        if (errors.equals("")) 
          errors = "\nUnknown user(s): "+'"'+persons[i]+'"';
        else
          errors = errors+", "+'"'+persons[i]+'"';
        // end if
      } // end if
    } // end for
    n = fNames.size();
    for (i=0; i<n; i++) {
      cFile = filePool.get((String)fNames.elementAt(i));
      try {
        cFile.delete(cEntry);
      } catch (IOException excep) {
        errors = errors+"\nError during delete operation on file "+
                 '"'+(String)fNames.elementAt(i)+'"'+"\n"+excep.toString();
        try { filePool.release((String)fNames.elementAt(i));
        } catch (IOException e) {}
      }
      try {
        filePool.release((String)fNames.elementAt(i));
      } catch (IOException excep) {
        errors = errors+"\nError during close operation on file "+
                 '"'+(String)fNames.elementAt(i)+'"'+"\n"+excep.toString();
      }
    } // end for
    // if a date is deleted not for all, then all copies of the invoked
    // persons must be updated if the user isn't the creator
    if ((!forAll) &&
        (!user.equals(cEntry.getCreator())) &&
        (cEntry.hasPerson(user))) {
      n = persons.length-1;
      String[] newPersons = new String[n];
      j = 0;
      for (i=0; i<n; i++) if (!persons[i].equals(user)) {
        newPersons[j] = persons[i];
        j++;
      } // end if end for
      errStr = null;
      CalendarEntry newEntry = (CalendarEntry)cEntry.clone();
      newEntry.setPersons(newPersons);
      updateDate(cEntry,newEntry,true);
      if (errStr != null) {
        errors = errors+"\n"+errStr;
        errStr = null;
      } // end if
    } // end if
    if (errors.equals("")) errStr = null;
      else errStr = "Error(s) during delete of date"+errors;
  } // end deleteDate

  public void updateDate(CalendarEntry oldEntry,
                         CalendarEntry newEntry, boolean forAll) {
    if ((!logedIn()) || (newEntry.isDeleted())) return;
    String creator             = newEntry.getCreator();
    String persons[]           = newEntry.getPersons();
    Date start                 = newEntry.getStart();
    boolean periodic           = newEntry.isPeriodic();
    Vector fNames              = new Vector();
    Vector vPersons            = new Vector();
    String errors              = "";
    CalendarEntry messageEntry = null;
    CalendarFile cFile;
    int i,n,mode;

    if (forAll || user.equals(creator)) {
      if (pwdTable.containsKey(creator)) {
        fNames.addElement(makeFileName(creator,start,periodic));
        vPersons.addElement(creator);
      }
      else {
        errors = "\nUnknown user(s): "+'"'+newEntry.getCreator()+'"';
      } // end if
    }
    for (i=0; i<persons.length; i++) {
      if (pwdTable.containsKey(persons[i])) {
        if (forAll || user.equals(persons[i])) {
          fNames.addElement(makeFileName(persons[i],start,periodic));
          vPersons.addElement(persons[i]);
        } // end if
      }
      else {
        if (errors.equals("")) 
          errors = "\nUnknown user(s): "+'"'+persons[i]+'"';
        else
          errors = errors+", "+'"'+persons[i]+'"';
        // end if
      } // end if
    } // end for
    n = fNames.size();
    if (n == 0) return; // Hm, nothing to update
    for (i=0; i<n; i++) {
      if (user.equals((String)vPersons.elementAt(i))) {
        // if user is target of update operation
        mode = CalendarFile.REMOVE_PERSONS;
      }
      else {
        // if user updates entry of other user
        mode = CalendarFile.REMOVE_PERSONS | CalendarFile.KEEP_NOTES;
      } // end if
      cFile = filePool.get((String)fNames.elementAt(i));
      try {
        messageEntry = cFile.update(oldEntry,newEntry,mode);
      } catch (IOException excep) {
        errors = errors+"\nError during update operation on file "+
                 '"'+(String)fNames.elementAt(i)+'"'+"\n"+excep.toString();
        try { filePool.release((String)fNames.elementAt(i));
        } catch (IOException e) {}
      }
      try {
        filePool.release((String)fNames.elementAt(i));
      } catch (IOException excep) {
        errors = errors+"\nError during close operation on file "+
                 '"'+(String)fNames.elementAt(i)+'"'+"\n"+excep.toString();
      }
      if ((!user.equals((String)vPersons.elementAt(i))) &&
          (messageEntry != null)) {
        // if the target is another user, the update operation must be notified
        //String fName = pwdTable.getFileNameShortcut(persons[i])+MESSAGE_EXT;
        String fName = pwdTable.getFileNameShortcut((String)vPersons.elementAt(i))+
                       MESSAGE_EXT;

        cFile = filePool.get(fName);
        try {
          cFile.write(messageEntry);
        } catch (IOException excep) {
          errors = errors+"\nError during write operation on file "+
                   '"'+fName+'"'+"\n"+excep.toString();
          try { filePool.release(fName);
          } catch (IOException e) {}
        }
        try {
          filePool.release(fName);
        } catch (IOException excep) {
          errors = errors+"\nError during close operation on file "+
                   '"'+fName+'"'+"\n"+excep.toString();
        }
      } // end if
    } // end for
    if (errors.equals("")) errStr = null;
      else errStr = "Error(s) during update of date"+errors;
  } // end updateDate

  public void endSession() {
  // closes all connections, frees all resources
    errStr = null;
  } // end endSession

  protected FilePool getFilePool() {
    return filePool;
  } // end getFilePool

  protected void setErrStr(String errStr) {
    this.errStr = errStr;
  } // end setErrStr

  private String makeFileName(String user, Date date, boolean isPeriodic) {
    if (isPeriodic) {
      return pwdTable.getFileNameShortcut(user)+PERIODIC_EXT;
    }
    else {
      Calendar calendar = CalendarCreator.get();
      calendar.setTime(date);
      return pwdTable.getFileNameShortcut(user)+
             formatter.format(calendar.getTime())+STANDARD_EXT;
    } // end if
  } // end makeFileName

  private boolean logedIn() {
    if (logedInFlag) return true;
    errStr   = "User is'nt loged in yet\nClient tried to invoke a"+
               " database operation without loging in before";
    return false;
  } // end logedIn

} // end FileDatabase

/* ******************************************************************
   class declarations
*********************************************************************/

class SingleFileEnumeration implements Enumeration {

  // instance variable declaration
  private FileDatabase fdb;
  private String fName;
  private String user;
  private boolean fullEnumeration;
  private Date from;
  private Date to;
  private boolean deleteOnRead;
  private CalendarFile cFile;
  private CalendarEntry cEntry;
  private long seekPos;

  // constructors
  public SingleFileEnumeration(FileDatabase fdb, String fName, String user,
                               boolean deleteOnRead)
  throws IOException {
    // used for a full enumeration of a file
    this.fdb          = fdb;
    this.fName        = fName;
    this.user         = user;
    fullEnumeration   = true;
    from              = null;
    to                = null;
    this.deleteOnRead = deleteOnRead; 
    cFile             = fdb.getFilePool().get(fName);
    cEntry            = new CalendarEntry();
    seekPos           = 0;
    read();
  } // end constructor SingleFileEnumeration

  public SingleFileEnumeration(FileDatabase fdb, String fName, String user,
                               Date from, Date to,
                               boolean deleteOnRead)
  throws IOException {
    // used for a partial enumeration of a file
    this.fdb          = fdb;
    this.fName        = fName;
    this.user         = user;
    fullEnumeration   = false;
    this.from         = from;
    this.to           = to;
    this.deleteOnRead = deleteOnRead; 
    cFile             = fdb.getFilePool().get(fName);
    cEntry            = new CalendarEntry();
    seekPos           = 0;
    read();
  } // end constructor SingleFileEnumeration

  // methods
  public boolean hasMoreElements() {

    return (cEntry != null);
  } // end hasMoreElements

  public Object nextElement() {
    CalendarEntry result = null;
    CalendarEntry oldVer = null;

    if (hasMoreElements()) {
      oldVer = cEntry.getOldVersion();
      result = (CalendarEntry)cEntry.clone();
      if (oldVer != null)
        result.setOldVersion((CalendarEntry)oldVer.clone());
      result.makePublicView(user);
      try {
        read();
      } catch (IOException excep) { cEntry = null; }
      return result;
    }
    else {
      throw new NoSuchElementException();
    } // end if
  } // end nextElement

  private void read() throws IOException {
    boolean done;
    do {
      try {
        if (deleteOnRead) seekPos = cFile.readAndDelete(cEntry,seekPos);
          else seekPos = cFile.read(cEntry,seekPos);
      } catch (IOException excep) {
          fdb.setErrStr("Error during read operation on file "+
                        '"'+fName+'"'+"\n"+excep.toString());
        try { fdb.getFilePool().release(fName); } catch (IOException e) {}
        cEntry = null;
        throw (IOException)excep.fillInStackTrace();
      }
      done = ((!cEntry.isDeleted()) && fullEnumeration) || cEntry.matches(from,to);
    } while ((seekPos != CalendarFile.EOF) && (!done));
    if (seekPos == CalendarFile.EOF) {
      cEntry = null;
      try {
        fdb.getFilePool().release(fName);
      } catch (IOException excep) {
        fdb.setErrStr("Error during close operation on file "+
                      '"'+fName+'"'+"\n"+excep.toString());
      }
    } // end if
  } // end read

} // end SingleFileEnumeration

//*******************************************************************

class MultipleFileEnumeration implements Enumeration {

  // instance variable declaration
  private FileDatabase fdb;
  private String fShortcut;
  private String fExtention;
  private String user;
  private Date from;
  private Date to;
  private Date cur;
  private String fName;
  private boolean noMoreFiles;
  private Calendar calendar;
  private CalendarFile cFile;
  private CalendarEntry cEntry;
  private long seekPos;
  private SimpleDateFormat formatter;

  // constructors
  public MultipleFileEnumeration(FileDatabase fdb, String fShortcut,
                                 String fExtention, String user,
                                 Date from, Date to)
  throws IOException {
    this.fdb          = fdb;
    this.from         = from;
    this.to           = to;
    this.fShortcut    = fShortcut;
    this.fExtention   = fExtention;
    this.user         = user;
    cur               = from;
    fName             = null;
    calendar          = CalendarCreator.get();
    noMoreFiles       = false;
    formatter         = new SimpleDateFormat("yyyyMM",CalendarCreator.getLocale());
    nextFile();
    cEntry            = new CalendarEntry();
    seekPos           = 0;
    read();
  } // end constructor MultipleFileEnumeration

  // methods
  public boolean hasMoreElements() {

    return (cEntry != null);
  } // end hasMoreElements

  public Object nextElement() {
    CalendarEntry result = null;

    if (hasMoreElements()) {
      result = (CalendarEntry)cEntry.clone();
      result.makePublicView(user);
      try {
        read();
      } catch (IOException excep) { cEntry = null; }
      return result;
    }
    else {
      throw new NoSuchElementException();
    } // end if
  } // end nextElement

  private void read() throws IOException {
    do {
      do {
        try {
          seekPos = cFile.read(cEntry,seekPos);
        } catch (IOException excep) {
          fdb.setErrStr("Error during read operation on file "+
                        '"'+fName+'"'+"\n"+excep.toString());
          try { fdb.getFilePool().release(fName); } catch (IOException e) {}
          cEntry = null;
          throw (IOException)excep.fillInStackTrace();
        }
      } while ((seekPos != CalendarFile.EOF) &&
               (!cEntry.matches(from,to)));
      if (seekPos == CalendarFile.EOF) nextFile();
    } while ((!noMoreFiles) &&
             (!cEntry.matches(from,to)));
    if (noMoreFiles) cEntry = null;
  } // end read

  private void nextFile() {
    if (fName != null) try {
      fdb.getFilePool().release(fName);
    } catch (IOException excep) {
      fdb.setErrStr("Error during close operation on file "+
                    '"'+fName+'"'+"\n"+excep.toString());
    }
    if ((from.equals(cur) || from.before(cur)) &&
        (to.after(cur))) {
      calendar.setTime(cur);
      fName   = fShortcut+formatter.format(calendar.getTime())+fExtention;
      cFile   = fdb.getFilePool().get(fName);
      seekPos = 0;
      calendar.add(Calendar.DATE,-calendar.get(Calendar.DAY_OF_MONTH)+1);
      calendar.add(Calendar.MONTH,1);
      cur = calendar.getTime();
    }
    else {
      fName       = null;
      cFile       = null;
      noMoreFiles = true;
    } // end if
  } // end nextFile

} // end MultipleFileEnumeration

/* ******************************************************************
   end of file
*********************************************************************/
