/* ******************************************************************

   author     : puehringer edgar

   compiler   : javac (jdk 1.1.5)

   class      : MsgBoxDlg
   date       : 28.11.97
   description: a message box dialog class with various button and
                image options
   modified   : 02.02.98 - auto cancel mode for applet operation added
                13.03.98 - dialog is no longer initially visible

*********************************************************************/

/* ******************************************************************
   import statements
*********************************************************************/

import java.awt.*;
import java.awt.image.*;
import java.awt.event.*;
import java.util.*;

/* ******************************************************************
   top level class declaration
*********************************************************************/

public class MsgBoxDlg extends Dialog implements ActionListener {

  // class variable declarations
  // MsgBoxDlg button flags
  public final static int OK               = 0x0000;
  public final static int OKSYSINFO        = 0x0001;
  public final static int OKCANCEL         = 0x0002;
  public final static int ABORTRETRYIGNORE = 0x0003;
  public final static int YESNOCANCEL      = 0x0004;
  public final static int YESNO            = 0x0005;
  public final static int RETRYCANCEL      = 0x0006;
  public final static int TYPEMASK         = 0x000F;

  // MsgBoxDlg icon flags
  public final static int ICONHAND         = 0x0010;
  public final static int ICONQUESTION     = 0x0020;
  public final static int ICONEXCLAMATION  = 0x0030;
  public final static int ICONASTERISK     = 0x0040;
  public final static int ICONMASK         = 0x00F0;
 
  // MsgBoxDlg icon aliases
  public final static int ICONINFORMATION  = ICONASTERISK;
  public final static int ICONSTOP         = ICONHAND;

  // MsgBoxDlg default button flags
  public final static int DEFBUTTON1       = 0x0000;
  public final static int DEFBUTTON2       = 0x0100;
  public final static int DEFBUTTON3       = 0x0200;
  public final static int DEFMASK          = 0x0F00;

  // MsgBoxDlg return values
  public final static int IDOK     = 1;
  public final static int IDCANCEL = 2;
  public final static int IDABORT  = 3;
  public final static int IDRETRY  = 4;
  public final static int IDIGNORE = 5;
  public final static int IDYES    = 6;
  public final static int IDNO     = 7;

  // string array with button labels
  private final static String[] btnLabels = {
    "OK",
    "OK SysInfo",
    "OK Cancel",
    "Abort Retry Ignore",
    "Yes No Cancel",
    "Yes No",
    "Retry Cancel"
  };

  // instance variable declarations
  private boolean autoCancel = false;
  private Frame parent;
  private int choice = IDOK;
  private Button focusBtn;
  private Component custCtrl = null;

  // inner classes
  class MsgBoxDlgListener extends WindowAdapter {

    // methods
    public void windowClosing(WindowEvent e) {
      setChoice(IDCANCEL);
      setVisible(false);
      dispose();
    } // end windowClosing

    public void windowOpened(WindowEvent e) {
      focusBtn.requestFocus();
    } // end windowOpened

    public void windowActivated(WindowEvent e) {
      focusBtn.requestFocus();
    } // end windowActivated

    public void windowDeactivated(WindowEvent e) {
      if (autoCancel) {
        setChoice(IDCANCEL);
        setVisible(false);
        dispose();
      } // end if

    } // end WindowDeactivated

  } // end MsgBoxDlgListener

  // constructors
  public MsgBoxDlg(Frame parent,String text, int type) {
    super(parent);
    this.parent = parent;
    init(text,type);
  } // end constructor MsgBoxDlg

  public MsgBoxDlg(Frame parent, boolean modal,String text, int type) {
    super(parent,modal);
    this.parent = parent;
    init(text,type);
  } // end constructor MsgBoxDlg

  public MsgBoxDlg(Frame parent, String title,String text, int type) {
    super(parent,title);
    this.parent = parent;
    init(text,type);
  } // end constructor MsgBoxDlg

  public MsgBoxDlg(Frame parent, String title,
                   boolean modal,String text, int type) {
    super(parent,title,modal);
    this.parent = parent;
    init(text,type);
  } // end constructor MsgBoxDlg

  public MsgBoxDlg(Frame parent, String title, boolean modal,String text,
                   Component custCtrl, int type) {
    super(parent,title,modal);
    this.parent   = parent;
    this.custCtrl = custCtrl;
    init(text,type);
  } // end constructor MsgBoxDlg

  // methods
  private void init(String text, int type) {
    int i;
    int nrOfBtns;
    int defBtnIndex;

    addWindowListener(new MsgBoxDlgListener());
    // This dialog box uses the grid bag layout to provide a pretty good layout
    GridBagLayout gridbag = new GridBagLayout(); 
    GridBagConstraints constraints = new GridBagConstraints();

    // create the widgets
    InsetsPanel pan    = new InsetsPanel(new Insets(15,20,15,20));
    LabelArea msgLabel = new LabelArea(text);

    // Create the icon image canvas specified with the type parameter
    // or use a custom control spezified by the constructor
    if (custCtrl == null) switch (type & ICONMASK) {
      case ICONHAND:
        custCtrl = new MemoryImageCanvas(HandImage.pixels,32,32);
      break;
      case ICONQUESTION:
        custCtrl = new MemoryImageCanvas(QuestionImage.pixels,32,32);
      break;
      case ICONEXCLAMATION:
        custCtrl = new MemoryImageCanvas(ExclamationImage.pixels,32,32);
      break;
      case ICONASTERISK:
        custCtrl = new MemoryImageCanvas(AsteriskImage.pixels,32,32);
      break;
      default:
        custCtrl = null;
    } // end switch end if

    StringTokenizer strTok = new StringTokenizer(btnLabels[type & TYPEMASK]);
    nrOfBtns    = strTok.countTokens();
    defBtnIndex = (type & DEFMASK) >> 8;
    if (defBtnIndex >= nrOfBtns) defBtnIndex = 0;
    InsetsPanel buttonPanel = new InsetsPanel(new Insets(15,0,0,0));
    buttonPanel.setLayout(new GridLayout(1,nrOfBtns,10,0));
    for (i=0; i<nrOfBtns; i++) {
      Button btn = new Button(strTok.nextToken());
      btn.addActionListener(this);
      buttonPanel.add(btn);
      if (i == defBtnIndex) focusBtn = btn;
    } // end for

    pan.setLayout(gridbag);

    constraints.fill = GridBagConstraints.NONE; 
    constraints.anchor = GridBagConstraints.CENTER; 
    constraints.weightx = 1.0; 
    constraints.weighty = 1.0; 
    constraints.gridheight = GridBagConstraints.RELATIVE; 
    if (custCtrl != null) {
      //constraints.insets = new Insets(10,10,0,0);
      constraints.gridwidth = GridBagConstraints.RELATIVE;
      gridbag.setConstraints(custCtrl, constraints); 
      pan.add(custCtrl);
    } // end if
    constraints.insets    = new Insets(0,15,0,15);
    constraints.gridwidth = GridBagConstraints.REMAINDER;
    gridbag.setConstraints(msgLabel,constraints); 
    pan.add(msgLabel);

    constraints.weightx    = 1.0; 
    constraints.weighty    = 1.0; 
    constraints.insets     = new Insets(0,0,0,0);
    constraints.gridwidth  = GridBagConstraints.REMAINDER;
    constraints.gridheight = GridBagConstraints.REMAINDER; 
    gridbag.setConstraints(buttonPanel,constraints); 
    pan.add(buttonPanel); 
  
    add(pan);
    pack();
    setResizable(false);
    Dimension screen = Toolkit.getDefaultToolkit().getScreenSize();
    setLocation((screen.width - getSize().width) / 2,
                (screen.height - getSize().height) / 2);
    //setVisible(true);
  } // end init

  public void actionPerformed(ActionEvent e) {
    String cmd = e.getActionCommand();

    if (cmd.equals("SysInfo")) {
      SysInfoDlg sysInfoDlg = new SysInfoDlg(parent,"System Information",
                                             isModal());
      if (autoCancel) sysInfoDlg.setAutoCancel(true);
    }
    else {
      if (cmd.equals("OK"))
        choice = IDOK;
      else if (cmd.equals("Abort"))
        choice = IDABORT;
      else if (cmd.equals("Retry"))
        choice = IDRETRY;
      else if (cmd.equals("Ignore"))
        choice = IDIGNORE;
      else if (cmd.equals("Yes"))
        choice = IDYES;
      else if (cmd.equals("No"))
        choice = IDNO;
      else // if cmd equals cancel
        choice = IDCANCEL;
      // end if
      setVisible(false);
      dispose();
    } // end if
  } // end actionPerformed

  public int getChoice() {
    return choice;
  } // end getChoice

  public void setChoice(int choice) {
    this.choice = choice;
  } // end getChoice

  public boolean getAutoCancel() {
    return autoCancel;
  } // end getAutoCancel

  public void setAutoCancel(boolean autoCancel) {
    this.autoCancel = autoCancel;
  } // end getAutoCancel

} // end MsgBoxDlg

/* ******************************************************************
   class declarations
*********************************************************************/

// the following classes represent icon images

class HandImage {

  // class variable declarations
  protected final static int pixels[] = {
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, -8388608,
    -8388608, -8388608, -8388608, -8388608,
    -8388608, -8388608, -8388608, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    -8388608, -8388608, -8388608, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -8388608,
    -8388608, -8388608, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, -8388608,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -8388608, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, -8388608, -8388608, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -8388608,
    -8388608, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    -8388608, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -8388608, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, -8388608,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -8388608, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, -8388608,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -8388608, -8355712,
    32768, 32768, 32768, 32768,
    32768, 32768, -8388608, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -1, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -1, -65536, -65536, -65536,
    -65536, -65536, -65536, -8388608,
    -8355712, 32768, 32768, 32768,
    32768, -8388608, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -1, -1, -1, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -1,
    -1, -1, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -8388608, 32768, 32768, 32768,
    32768, -8388608, -65536, -65536,
    -65536, -65536, -65536, -1,
    -1, -1, -1, -1,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -1, -1,
    -1, -1, -1, -65536,
    -65536, -65536, -65536, -65536,
    -8388608, -8355712, 32768, 32768,
    32768, -8388608, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -1, -1, -1, -1,
    -1, -65536, -65536, -65536,
    -65536, -1, -1, -1,
    -1, -1, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -8388608, -8355712, -8355712, 32768,
    -8388608, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -1, -1, -1,
    -1, -1, -65536, -65536,
    -1, -1, -1, -1,
    -1, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -8388608, -8355712, 32768,
    -8388608, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -8388608, -8355712, 32768,
    -8388608, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -8388608, -8355712, -8355712,
    -8388608, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -1, -1, -1, -1,
    -1, -1, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -8388608, -8355712, -8355712,
    -8388608, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -1, -1, -1, -1,
    -1, -1, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -8388608, -8355712, -8355712,
    -8388608, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -8388608, -8355712, -8355712,
    -8388608, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -8388608, -8355712, -8355712,
    -8388608, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -1, -1, -1,
    -1, -1, -65536, -65536,
    -1, -1, -1, -1,
    -1, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -8388608, -8355712, -8355712,
    32768, -8388608, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -1, -1, -1, -1,
    -1, -65536, -65536, -65536,
    -65536, -1, -1, -1,
    -1, -1, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -8388608, -8355712, -8355712, -8355712,
    32768, -8388608, -65536, -65536,
    -65536, -65536, -65536, -1,
    -1, -1, -1, -1,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -1, -1,
    -1, -1, -1, -65536,
    -65536, -65536, -65536, -65536,
    -8388608, -8355712, -8355712, -8355712,
    32768, -8388608, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -1, -1, -1, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -1,
    -1, -1, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -8388608, -8355712, -8355712, 32768,
    32768, 32768, -8388608, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -1, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -1, -65536, -65536, -65536,
    -65536, -65536, -65536, -8388608,
    -8355712, -8355712, -8355712, 32768,
    32768, 32768, 32768, -8388608,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -8388608, -8355712,
    -8355712, -8355712, -8355712, 32768,
    32768, 32768, 32768, -8388608,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -8388608, -8355712,
    -8355712, -8355712, 32768, 32768,
    32768, 32768, 32768, 32768,
    -8388608, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -8388608, -8355712, -8355712,
    -8355712, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, -8388608, -8388608, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -8388608,
    -8388608, -8355712, -8355712, -8355712,
    -8355712, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, -8355712, -8388608,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -8388608, -8355712,
    -8355712, -8355712, -8355712, -8355712,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, -8355712,
    -8388608, -8388608, -8388608, -65536,
    -65536, -65536, -65536, -65536,
    -65536, -65536, -65536, -8388608,
    -8388608, -8388608, -8355712, -8355712,
    -8355712, -8355712, -8355712, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, -8355712, -8355712, -8388608,
    -8388608, -8388608, -8388608, -8388608,
    -8388608, -8388608, -8388608, -8355712,
    -8355712, -8355712, -8355712, -8355712,
    -8355712, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, -8355712, -8355712,
    -8355712, -8355712, -8355712, -8355712,
    -8355712, -8355712, -8355712, -8355712,
    -8355712, -8355712, -8355712, -8355712,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, -8355712, -8355712, -8355712,
    -8355712, -8355712, -8355712, -8355712,
    -8355712, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768
  };

} // end HandImage

// ******************************************************************

class QuestionImage {

  // class variable declarations
  protected final static int pixels[] = {
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, -8355712,
    -8355712, -8355712, -8355712, -8355712,
    -8355712, -8355712, -8355712, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    -8355712, -8355712, -8355712, -4144960,
    -1, -1, -1, -1,
    -1, -1, -4144960, -8355712,
    -8355712, -8355712, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, -8355712, -8355712,
    -4144960, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -4144960, -8355712, -8355712,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, -8355712, -4144960, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -4144960,
    -8355712, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    -8355712, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -16777216, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, -8355712,
    -1, -1, -1, -1,
    -1, -1, -1, -4144960,
    -16776961, -16776961, -16776961, -16776961,
    -16776961, -16776961, -4144960, -1,
    -1, -1, -1, -1,
    -1, -1, -16777216, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, -8355712, -1,
    -1, -1, -1, -1,
    -1, -1, -4144960, -16776961,
    -4144960, -1, -1, -16776961,
    -16776961, -16776961, -16776961, -4144960,
    -1, -1, -1, -1,
    -1, -1, -1, -16777216,
    32768, 32768, 32768, 32768,
    32768, -8355712, -4144960, -1,
    -1, -1, -1, -1,
    -1, -1, -16776961, -16776961,
    -1, -1, -1, -1,
    -16776961, -16776961, -16776961, -16776961,
    -1, -1, -1, -1,
    -1, -1, -1, -4144960,
    -16777216, 32768, 32768, 32768,
    32768, -8355712, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -16776961, -16776961,
    -16776961, -16776961, -1, -1,
    -16776961, -16776961, -16776961, -16776961,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -16777216, -8355712, 32768, 32768,
    -8355712, -4144960, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -16776961, -16776961,
    -16776961, -16776961, -1, -4144960,
    -16776961, -16776961, -16776961, -16776961,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -4144960, -16777216, -8355712, 32768,
    -8355712, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -4144960, -16776961,
    -16776961, -4144960, -1, -16776961,
    -16776961, -16776961, -16776961, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -16777216, -8355712, 32768,
    -8355712, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -4144960, -16776961,
    -16776961, -16776961, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -16777216, -8355712, -8355712,
    -8355712, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -16776961, -16776961,
    -16776961, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -16777216, -8355712, -8355712,
    -8355712, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -16776961, -16776961,
    -4144960, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -16777216, -8355712, -8355712,
    -8355712, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -16776961, -16776961,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -16777216, -8355712, -8355712,
    -8355712, -4144960, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -4144960, -16777216, -8355712, -8355712,
    32768, -8355712, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -4144960, -16776961, -16776961,
    -4144960, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -16777216, -8355712, -8355712, -8355712,
    32768, -8355712, -4144960, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -16776961, -16776961, -16776961,
    -16776961, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -4144960,
    -16777216, -8355712, -8355712, -8355712,
    32768, 32768, -8355712, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -16776961, -16776961, -16776961,
    -16776961, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -16777216,
    -8355712, -8355712, -8355712, 32768,
    32768, 32768, 32768, -16777216,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -4144960, -16776961, -16776961,
    -4144960, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -16777216, -8355712,
    -8355712, -8355712, -8355712, 32768,
    32768, 32768, 32768, 32768,
    -16777216, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -16777216, -8355712, -8355712,
    -8355712, -8355712, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, -16777216, -4144960, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -4144960,
    -16777216, -8355712, -8355712, -8355712,
    -8355712, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, -16777216, -16777216,
    -4144960, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -4144960, -16777216, -16777216,
    -8355712, -8355712, -8355712, -8355712,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, -8355712,
    -16777216, -16777216, -16777216, -4144960,
    -1, -1, -1, -1,
    -1, -1, -4144960, -16777216,
    -16777216, -16777216, -8355712, -8355712,
    -8355712, -8355712, -8355712, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    -8355712, -8355712, -8355712, -16777216,
    -16777216, -16777216, -4144960, -1,
    -1, -1, -16777216, -8355712,
    -8355712, -8355712, -8355712, -8355712,
    -8355712, -8355712, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, -8355712, -8355712,
    -8355712, -8355712, -16777216, -1,
    -1, -1, -16777216, -8355712,
    -8355712, -8355712, -8355712, -8355712,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, -8355712, -16777216, -1,
    -1, -1, -16777216, -8355712,
    -8355712, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, -16777216,
    -1, -1, -16777216, -8355712,
    -8355712, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    -16777216, -1, -16777216, -8355712,
    -8355712, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, -16777216, -16777216, -8355712,
    -8355712, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, -8355712, -8355712,
    -8355712, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, -8355712,
    -8355712, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768
  };

} // end QuestionImage

// ******************************************************************

class ExclamationImage {

  // class variable declarations
  protected final static int pixels[] = {
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, -8355840, -8355840, -8355840,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    -8355840, -256, -256, -4144960,
    -16777216, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, -8355840,
    -256, -256, -256, -256,
    -4144960, -16777216, -8355712, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, -8355840,
    -256, -256, -256, -256,
    -256, -16777216, -8355712, -8355712,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, -8355840, -256,
    -256, -256, -256, -256,
    -256, -4144960, -16777216, -8355712,
    -8355712, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, -8355840, -256,
    -256, -256, -256, -256,
    -256, -256, -16777216, -8355712,
    -8355712, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, -8355840, -256, -256,
    -256, -256, -256, -256,
    -256, -256, -4144960, -16777216,
    -8355712, -8355712, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, -8355840, -256, -256,
    -256, -256, -256, -256,
    -256, -256, -256, -16777216,
    -8355712, -8355712, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    -8355840, -256, -256, -256,
    -256, -256, -256, -256,
    -256, -256, -256, -4144960,
    -16777216, -8355712, -8355712, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    -8355840, -256, -256, -256,
    -4144960, -16777216, -16777216, -16777216,
    -4144960, -256, -256, -256,
    -16777216, -8355712, -8355712, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, -8355840,
    -256, -256, -256, -256,
    -16777216, -16777216, -16777216, -16777216,
    -16777216, -256, -256, -256,
    -4144960, -16777216, -8355712, -8355712,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, -8355840,
    -256, -256, -256, -256,
    -16777216, -16777216, -16777216, -16777216,
    -16777216, -256, -256, -256,
    -256, -16777216, -8355712, -8355712,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, -8355840, -256,
    -256, -256, -256, -256,
    -16777216, -16777216, -16777216, -16777216,
    -16777216, -256, -256, -256,
    -256, -4144960, -16777216, -8355712,
    -8355712, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, -8355840, -256,
    -256, -256, -256, -256,
    -16777216, -16777216, -16777216, -16777216,
    -16777216, -256, -256, -256,
    -256, -256, -16777216, -8355712,
    -8355712, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, -8355840, -256, -256,
    -256, -256, -256, -256,
    -16777216, -16777216, -16777216, -16777216,
    -16777216, -256, -256, -256,
    -256, -256, -4144960, -16777216,
    -8355712, -8355712, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, -8355840, -256, -256,
    -256, -256, -256, -256,
    -8355840, -16777216, -16777216, -16777216,
    -8355840, -256, -256, -256,
    -256, -256, -256, -16777216,
    -8355712, -8355712, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    -8355840, -256, -256, -256,
    -256, -256, -256, -256,
    -4144960, -16777216, -16777216, -16777216,
    -4144960, -256, -256, -256,
    -256, -256, -256, -4144960,
    -16777216, -8355712, -8355712, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    -8355840, -256, -256, -256,
    -256, -256, -256, -256,
    -256, -16777216, -16777216, -16777216,
    -256, -256, -256, -256,
    -256, -256, -256, -256,
    -16777216, -8355712, -8355712, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, -8355840,
    -256, -256, -256, -256,
    -256, -256, -256, -256,
    -256, -8355840, -16777216, -8355840,
    -256, -256, -256, -256,
    -256, -256, -256, -256,
    -4144960, -16777216, -8355712, -8355712,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, -8355840,
    -256, -256, -256, -256,
    -256, -256, -256, -256,
    -256, -4144960, -16777216, -4144960,
    -256, -256, -256, -256,
    -256, -256, -256, -256,
    -256, -16777216, -8355712, -8355712,
    32768, 32768, 32768, 32768,
    32768, 32768, -8355840, -256,
    -256, -256, -256, -256,
    -256, -256, -256, -256,
    -256, -256, -16777216, -256,
    -256, -256, -256, -256,
    -256, -256, -256, -256,
    -256, -4144960, -16777216, -8355712,
    -8355712, 32768, 32768, 32768,
    32768, 32768, -8355840, -256,
    -256, -256, -256, -256,
    -256, -256, -256, -256,
    -256, -256, -256, -256,
    -256, -256, -256, -256,
    -256, -256, -256, -256,
    -256, -256, -16777216, -8355712,
    -8355712, 32768, 32768, 32768,
    32768, -8355840, -256, -256,
    -256, -256, -256, -256,
    -256, -256, -256, -256,
    -256, -4144960, -16777216, -16777216,
    -4144960, -256, -256, -256,
    -256, -256, -256, -256,
    -256, -256, -4144960, -16777216,
    -8355712, -8355712, 32768, 32768,
    32768, -8355840, -256, -256,
    -256, -256, -256, -256,
    -256, -256, -256, -256,
    -256, -16777216, -16777216, -16777216,
    -16777216, -256, -256, -256,
    -256, -256, -256, -256,
    -256, -256, -256, -16777216,
    -8355712, -8355712, 32768, 32768,
    -8355840, -256, -256, -256,
    -256, -256, -256, -256,
    -256, -256, -256, -256,
    -256, -16777216, -16777216, -16777216,
    -16777216, -256, -256, -256,
    -256, -256, -256, -256,
    -256, -256, -256, -4144960,
    -16777216, -8355712, -8355712, 32768,
    -8355840, -256, -256, -256,
    -256, -256, -256, -256,
    -256, -256, -256, -256,
    -256, -4144960, -16777216, -16777216,
    -4144960, -256, -256, -256,
    -256, -256, -256, -256,
    -256, -256, -256, -256,
    -16777216, -8355712, -8355712, 32768,
    -8355840, -256, -256, -256,
    -256, -256, -256, -256,
    -256, -256, -256, -256,
    -256, -256, -256, -256,
    -256, -256, -256, -256,
    -256, -256, -256, -256,
    -256, -256, -256, -256,
    -16777216, -8355712, -8355712, -8355712,
    -8355840, -256, -256, -256,
    -256, -256, -256, -256,
    -256, -256, -256, -256,
    -256, -256, -256, -256,
    -256, -256, -256, -256,
    -256, -256, -256, -256,
    -256, -256, -256, -4144960,
    -16777216, -8355712, -8355712, -8355712,
    32768, -8355840, -256, -256,
    -256, -256, -256, -256,
    -256, -256, -256, -256,
    -256, -256, -256, -256,
    -256, -256, -256, -256,
    -256, -256, -256, -256,
    -256, -256, -4144960, -16777216,
    -8355712, -8355712, -8355712, -8355712,
    32768, 32768, -8355840, -16777216,
    -16777216, -16777216, -16777216, -16777216,
    -16777216, -16777216, -16777216, -16777216,
    -16777216, -16777216, -16777216, -16777216,
    -16777216, -16777216, -16777216, -16777216,
    -16777216, -16777216, -16777216, -16777216,
    -16777216, -16777216, -16777216, -8355712,
    -8355712, -8355712, -8355712, -8355712,
    32768, 32768, 32768, 32768,
    -8355712, -8355712, -8355712, -8355712,
    -8355712, -8355712, -8355712, -8355712,
    -8355712, -8355712, -8355712, -8355712,
    -8355712, -8355712, -8355712, -8355712,
    -8355712, -8355712, -8355712, -8355712,
    -8355712, -8355712, -8355712, -8355712,
    -8355712, -8355712, -8355712, 32768,
    32768, 32768, 32768, 32768,
    32768, -8355712, -8355712, -8355712,
    -8355712, -8355712, -8355712, -8355712,
    -8355712, -8355712, -8355712, -8355712,
    -8355712, -8355712, -8355712, -8355712,
    -8355712, -8355712, -8355712, -8355712,
    -8355712, -8355712, -8355712, -8355712,
    -8355712, -8355712, 32768, 32768
  };

} // end ExclamationImage

// ******************************************************************

class AsteriskImage {

  // class variable declarations
  protected final static int pixels[] = {
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, -8355712,
    -8355712, -8355712, -8355712, -8355712,
    -8355712, -8355712, -8355712, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    -8355712, -8355712, -8355712, -4144960,
    -1, -1, -1, -1,
    -1, -1, -4144960, -8355712,
    -8355712, -8355712, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, -8355712, -8355712,
    -4144960, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -4144960, -8355712, -8355712,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, -8355712, -4144960, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -4144960,
    -8355712, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    -8355712, -1, -1, -1,
    -1, -1, -1, -1,
    -4144960, -16776961, -16776961, -16776961,
    -16776961, -4144960, -1, -1,
    -1, -1, -1, -1,
    -1, -16777216, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, -8355712,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -16776961, -16776961, -16776961, -16776961,
    -16776961, -16776961, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -16777216, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, -8355712, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -16776961, -16776961, -16776961, -16776961,
    -16776961, -16776961, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -16777216,
    32768, 32768, 32768, 32768,
    32768, -8355712, -4144960, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -4144960, -16776961, -16776961, -16776961,
    -16776961, -4144960, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -4144960,
    -16777216, 32768, 32768, 32768,
    32768, -8355712, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -16777216, -8355712, 32768, 32768,
    -8355712, -4144960, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -4144960, -16777216, -8355712, 32768,
    -8355712, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -16776961,
    -16776961, -16776961, -16776961, -16776961,
    -16776961, -16776961, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -16777216, -8355712, 32768,
    -8355712, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -16776961, -16776961, -16776961,
    -16776961, -16776961, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -16777216, -8355712, -8355712,
    -8355712, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -16776961, -16776961, -16776961,
    -16776961, -16776961, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -16777216, -8355712, -8355712,
    -8355712, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -16776961, -16776961, -16776961,
    -16776961, -16776961, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -16777216, -8355712, -8355712,
    -8355712, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -16776961, -16776961, -16776961,
    -16776961, -16776961, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -16777216, -8355712, -8355712,
    -8355712, -4144960, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -16776961, -16776961, -16776961,
    -16776961, -16776961, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -4144960, -16777216, -8355712, -8355712,
    32768, -8355712, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -16776961, -16776961, -16776961,
    -16776961, -16776961, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -16777216, -8355712, -8355712, -8355712,
    32768, -8355712, -4144960, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -16776961, -16776961, -16776961,
    -16776961, -16776961, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -4144960,
    -16777216, -8355712, -8355712, -8355712,
    32768, 32768, -8355712, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -16776961,
    -16776961, -16776961, -16776961, -16776961,
    -16776961, -16776961, -16776961, -16776961,
    -1, -1, -1, -1,
    -1, -1, -1, -16777216,
    -8355712, -8355712, -8355712, 32768,
    32768, 32768, 32768, -16777216,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -16777216, -8355712,
    -8355712, -8355712, -8355712, 32768,
    32768, 32768, 32768, 32768,
    -16777216, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -16777216, -8355712, -8355712,
    -8355712, -8355712, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, -16777216, -4144960, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -4144960,
    -16777216, -8355712, -8355712, -8355712,
    -8355712, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, -16777216, -16777216,
    -4144960, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -1, -1, -1,
    -1, -4144960, -16777216, -16777216,
    -8355712, -8355712, -8355712, -8355712,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, -8355712,
    -16777216, -16777216, -16777216, -4144960,
    -1, -1, -1, -1,
    -1, -1, -4144960, -16777216,
    -16777216, -16777216, -8355712, -8355712,
    -8355712, -8355712, -8355712, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    -8355712, -8355712, -8355712, -16777216,
    -16777216, -16777216, -4144960, -1,
    -1, -1, -16777216, -8355712,
    -8355712, -8355712, -8355712, -8355712,
    -8355712, -8355712, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, -8355712, -8355712,
    -8355712, -8355712, -16777216, -1,
    -1, -1, -16777216, -8355712,
    -8355712, -8355712, -8355712, -8355712,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, -8355712, -16777216, -1,
    -1, -1, -16777216, -8355712,
    -8355712, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, -16777216,
    -1, -1, -16777216, -8355712,
    -8355712, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    -16777216, -1, -16777216, -8355712,
    -8355712, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, -16777216, -16777216, -8355712,
    -8355712, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, -8355712, -8355712,
    -8355712, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, -8355712,
    -8355712, 32768, 32768, 32768,
    32768, 32768, 32768, 32768,
    32768, 32768, 32768, 32768
  };

} // end AsteriskImage

/* ******************************************************************
   end of file
*********************************************************************/
