/* ******************************************************************

   author     : puehringer edgar

   compiler   : javac             

   class      : TabbedChoice
   date       : 16.01.98
   description: a subclass of canvas, which acts as Choice and has
                the visible representation of tabbed panels

*********************************************************************/

/* ******************************************************************
   import statements
*********************************************************************/

import java.awt.*;
import java.awt.event.*;
import java.util.*;

/* ******************************************************************
   top level class declaration
*********************************************************************/

public class TabbedChoice extends Canvas implements ItemSelectable {

  // class variable declarations
  private final static int FONT_SIZE   = 12;
  private final static int DEF_ASCENT  = 10;
  private final static int DEF_LEADING = 0;
  private final static int DEF_DESCENT = 3;

  // instance variable declarations
  private Vector vector;
  private int selectedIndex;
  private int oldIndex;
  private Vector listenerVector;
  private int baseline;
  private int labelHeight;
  private boolean sizeAvailable;
  private Dimension size;
  private int xOfs[];
  private int oldVectorSize;

  // constructors
  public TabbedChoice() {
    vector         = new Vector();
    selectedIndex  = 0;
    oldIndex       = 0;
    listenerVector = new Vector();
    sizeAvailable  = false;
    xOfs           = new int[0];
    oldVectorSize  = 0;
    enableEvents(AWTEvent.MOUSE_EVENT_MASK);
  } // end constructor TabbedChoice

  // methods
  public synchronized void add(String item) {
    if (item == null) throw new NullPointerException();
    vector.addElement(item);
    repaintAndNotify();
  } // end add

  public synchronized void addItem(String item) {
    add(item);
  } // end addItem

  public synchronized void addItemListener(ItemListener l) {
    listenerVector.addElement(l);
  } // end addItemListener

  public String getItem(int index) {
    if (vector.size() > 0) return (String)vector.elementAt(selectedIndex);
      else return null;
  } // end getItem

  public int getItemCount() {
    return vector.size();
  } // end getItemCount

  public int getSelectedIndex() {
    return selectedIndex;
  } // end getSelectedIndex

  public synchronized String getSelectedItem() {
    return getItem(selectedIndex);
  } // end getSelectedItem

  public Object[] getSelectedObjects() {
    Object[] objects = new Object[1];
    objects[0]       = getSelectedItem();
    return objects;
  } // end getSelectedObject

  public synchronized void insert(String item, int index) {
    if (index < 0) throw new IllegalArgumentException();
    vector.insertElementAt(item,index);
    if (selectedIndex >= index) selectedIndex++;
    repaintAndNotify();
  } // end insert

  public synchronized void remove(int position) {
    vector.removeElementAt(position);
    if ((selectedIndex >= position) && (selectedIndex > 0)) selectedIndex--;
    repaintAndNotify();
  } // end remove

  public synchronized void remove(String item) {
    int i = vector.indexOf(item);
    if (i < 0) throw new IllegalArgumentException();
    remove(i);
  } // end remove

  public synchronized void removeAll() {
    vector.removeAllElements();
    selectedIndex = 0;
    repaintAndNotify();
  } // end removeAll

  public synchronized void removeItemListener(ItemListener l) {
    listenerVector.removeElement(l);
  } // end addItemListener

  public synchronized void select(int pos) {
    if ((pos < 0) || (pos >= vector.size())) throw new IllegalArgumentException();
    selectedIndex = pos;
    repaintAndNotify();
  } // end select

  public synchronized void select(String str) {
    int i = vector.indexOf(str);
    if (i >= 0) {
      select(i);
      repaintAndNotify();
    } // end if
  } // end select

  protected void repaintAndNotify() {
    int i;

    if (vector.size() != oldVectorSize) {
      oldVectorSize = vector.size();
      sizeAvailable = false;
    } // end if
    repaint();
    if (selectedIndex != oldIndex) {
      oldIndex = selectedIndex;
      // notify listeners
      ItemEvent ie  = new ItemEvent(this,ItemEvent.ITEM_STATE_CHANGED,
                                    vector.elementAt(selectedIndex),
                                    ItemEvent.SELECTED);
      for (i=0; i<listenerVector.size(); i++) {
        ((ItemListener)listenerVector.elementAt(i)).itemStateChanged(ie);
      } // end for
    } // end if
  } // end repaintAndNotify

  public void paint(Graphics g) {
    FontMetrics fm;
    Font font = new Font(g.getFont().getName(),
                         g.getFont().getStyle(),
                         FONT_SIZE);
    int i,y;
    int n = vector.size();

    if (!sizeAvailable) size = calculateSize(g);
    if (n == 0) return;
    g.setFont(font);
    for (i=0; i<n; i++) {
      g.setColor(SystemColor.control);
      if (selectedIndex == i) {
        y = 0;
      }
      else {
        g.drawLine(xOfs[i],0,xOfs[i+1],0);
        y = 1;
      } // end if
      g.fill3DRect(xOfs[i],y,xOfs[i+1]-xOfs[i]-1,size.height+1-y,true);
      g.setColor(SystemColor.controlText);
      g.drawString((String)vector.elementAt(i),xOfs[i]+4,y+baseline);
      if (selectedIndex != i) {
        g.setColor(SystemColor.controlLtHighlight);
        g.drawLine(xOfs[i],size.height-1,xOfs[i+1]-1,size.height-1);
      } // end if
    } // end for
    g.setColor(SystemColor.controlLtHighlight);
    g.drawLine(xOfs[n],size.height-1,getSize().width,size.height-1);
  } // end paint

  public void processMouseEvent(MouseEvent e) {
    if (e.getID() == MouseEvent.MOUSE_CLICKED) {
        int n = vector.size();
        int i = 0;
        int x = e.getX();
        while (i<n) {
          if ((x>=xOfs[i]) && (x<xOfs[i+1])) {
            selectedIndex = i;
            repaintAndNotify();
            break;
          } // end if
          i++;
        } // end while
    } // end if
    super.processMouseEvent(e);
  } // end processMouseEvent

  private Dimension calculateSize(Graphics g) {
    Font font;
    FontMetrics fm;
    int ascent,descent,leading;
    int i,n;
    int width;
    String str;
    char chars[];

    if (g == null) g = getGraphics();
    if (g != null) { // if it didn't work
      font = new Font(g.getFont().getName(),g.getFont().getStyle(),FONT_SIZE);
      g.setFont(font);
      fm            = g.getFontMetrics();
      ascent        = fm.getAscent();
      descent       = fm.getDescent();
      leading       = fm.getLeading();
      n             = vector.size();
      if (n >= xOfs.length) xOfs = new int[n+1];
      xOfs[0] = 0;
      for (i=1; i<=n; i++) {
        str   = (String)vector.elementAt(i-1);
        chars = new char[str.length()];
        str.getChars(0,str.length(),chars,0);
        xOfs[i] = xOfs[i-1]+fm.charsWidth(chars,0,chars.length)+8;
      } // end for
      width = xOfs[n];
      sizeAvailable = true;
    }
    else {
      ascent  = DEF_ASCENT;
      descent = DEF_DESCENT;
      leading = DEF_LEADING;
      width   = 100;
    } // end if
    labelHeight = ascent+descent+leading;
    baseline    = leading/2+ascent;
    return new Dimension(width,labelHeight+3);
  } // end calculateSize

  public Dimension getPreferredSize() {
    if (!sizeAvailable) size = calculateSize(null);
    return size;
  } // end getPreferredSize

  public Dimension getMinimumSize() {
    return getPreferredSize();
  } // end getMinimumSize

  public Dimension getMaximumSize() {
    Dimension d = getPreferredSize();
    d.width = 1024;
    return d;
  } // end getMaximumSize

} // end TabbedChoice

/* ******************************************************************
   end of file
*********************************************************************/
